@@ -1,18 +1,18 @@
-# Copyrights 2008-2009 by Mark Overmeer.
+# Copyrights 2008-2014 by [Mark Overmeer].
 #  For other contributors see ChangeLog.
 # See the manual pages for details on the licensing terms.
-# Pod stripped from pm file by OODoc 1.06.
+# Pod stripped from pm file by OODoc 2.01.
 use warnings;
 use strict;
 
 # extends the implementation of Geo::GML, autoloaded
 package Geo::GML;
 use vars '$VERSION';
-$VERSION = '0.15';
+$VERSION = '0.16';
 
 
 use Log::Report 'geo-gml', syntax => 'SHORT';
-use Geo::Point         ();
+use Geo::Point  ();
 
 
 #---------------------------------
@@ -31,7 +31,8 @@ sub GPtoGML($@)
     if($self->version lt 3)
     {   local $args{_srsName} = $srs;
         $data
-        = $object->isa('Geo::Surface') ? $self->_gml2_surface($object, \%args)
+        = $object->isa('Geo::Space')   ? $self->_gml2_space($object, \%args)
+        : $object->isa('Geo::Surface') ? $self->_gml2_surface($object, \%args)
         : $object->isa('Geo::Line')    ? $self->_gml2_line($object, \%args)
         : $object->isa('Geo::Point')   ? $self->_gml2_point($object, \%args)
         : $object->isa('Geo::Shape')   ? $self->_gml2_shape($object, \%args)
@@ -40,7 +41,8 @@ sub GPtoGML($@)
     }
     else
     {   $data
-        = $object->isa('Geo::Surface') ? $self->_gml3_surface($object, \%args)
+        = $object->isa('Geo::Space')   ? $self->_gml3_space($object, \%args)
+        : $object->isa('Geo::Surface') ? $self->_gml3_surface($object, \%args)
         : $object->isa('Geo::Line')    ? $self->_gml3_line($object, \%args)
         : $object->isa('Geo::Point')   ? $self->_gml3_point($object, \%args)
         : $object->isa('Geo::Shape')   ? $self->_gml3_shape($object, \%args)
@@ -58,13 +60,14 @@ sub GPtoGML($@)
 ## GML2
 #
 
-sub _gml2_surface($$)
-{   my ($self, $surface, $args) = @_;
+sub _gml2_space($$)
+{   my ($self, $space, $args) = @_;
 
+    # wrong: Space can contain other objects as well.
     my @members;
-    foreach my $c ($surface->components)
-    {   my $outer = $self->_gml2_line($c->outer, $args);
-        my @inner = map { $self->_gml2_line($_, $args) } $c->inner;
+    foreach my $c ($space->components)
+    {   my $outer = $self->_gml2_line($c->geoOuter, $args);
+        my @inner = map { $self->_gml2_line($_, $args) } $c->geoInner;
         my %poly  = ( gml_outerBoundaryIs => $outer
                     , gml_innerBoundaryIs => \@inner);
         push @members, +{ gml_polygonMember => {gml_Polygon => \%poly} };
@@ -77,6 +80,18 @@ sub _gml2_surface($$)
     };
 }
 
+sub _gml2_surface($$)
+{   my ($self, $surface, $args) = @_;
+
+    my $outer = $self->_gml2_line($surface->geoOuter, $args);
+    my @inner = map { $self->_gml2_line($_, $args) } $surface->geoInner;
+    my %poly  = ( gml_outerBoundaryIs => $outer
+                , gml_innerBoundaryIs => \@inner);
+   +{ gml_Polygon => \%poly
+    , srsName     => $args->{_srsName}
+    };
+}
+
 sub _gml2_line($$)
 {   my ($self, $line, $args) = @_;
     defined $line or return;
@@ -114,13 +129,13 @@ sub _gml2_shape($$)
 ## GML3
 #
 
-sub _gml3_surface($$)
-{   my ($self, $surface, $args) = @_;
+sub _gml3_space($$)
+{   my ($self, $space, $args) = @_;
     my @members;
 
-    foreach my $c ($surface->components)
-    {   my $outer = $self->_gml3_line($c->outer, $args);
-        my @inner = map { $self->_gml3_line($_, $args) } $c->inner;
+    foreach my $c ($space->components)
+    {   my $outer = $self->_gml3_line($c->geoOuter, $args);
+        my @inner = map { $self->_gml3_line($_, $args) } $c->geoInner;
         my %poly  = (gml_exterior => $outer, gml_interior => \@inner);
         push @members, +{ gml_Polygon => \%poly };
     }
@@ -135,6 +150,16 @@ sub _gml3_surface($$)
     };
 }
 
+sub _gml3_surface($$)
+{   my ($self, $surface, $args) = @_;
+    my @members;
+
+    my $outer = $self->_gml3_line($surface->geoOuter, $args);
+    my @inner = map { $self->_gml3_line($_, $args) } $surface->geoInner;
+    my %poly  = (gml_exterior => $outer, gml_interior => \@inner);
+    +{ gml_Polygon => \%poly };
+}
+
 sub _gml3_line($$)
 {   my ($self, $line, $args) = @_;
     $line or return;
